@@ -1,11 +1,11 @@
 `plot.draw.latent` <-
-function(x, graphtype = "png", ...) {
-   if(is.null(x$rootname)) {
+function(x, rootname = NULL, graphtype = "pdf", ...) {
+   if(is.null(rootname)) {
       warning("Cannot plot if rootname NULL")
       res <- list(retval = 256, cmnd = NULL)
    } else {
-      cmnd <- paste("dot -T", graphtype, " ", x$rootname, ".dt -o ",
-         x$rootname, ".", graphtype, sep = "")
+      cmnd <- paste("dot -T", graphtype, " ", rootname, ".gv -o ",
+         rootname, ".", graphtype, sep = "")
       retval <- system(cmnd)
       res <- list(retval = retval, cmnd = cmnd)
    }
